# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spice.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import utils_pb2 as utils__pb2
from . import circuit_pb2 as circuit__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="spice.proto",
    package="vlsir.spice",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0bspice.proto\x12\x0bvlsir.spice\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0butils.proto\x1a\rcircuit.proto"\xab\x01\n\x08SimInput\x12#\n\x03pkg\x18\x01 \x01(\x0b\x32\x16.vlsir.circuit.Package\x12\x0b\n\x03top\x18\x02 \x01(\t\x12%\n\x04opts\x18\n \x03(\x0b\x32\x17.vlsir.spice.SimOptions\x12!\n\x02\x61n\x18\x0b \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x0c \x03(\x0b\x32\x14.vlsir.spice.Control"4\n\tSimResult\x12\'\n\x02\x61n\x18\x01 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"W\n\nSimOptions\x12\x0c\n\x04temp\x18\x01 \x01(\x01\x12\x0c\n\x04tnom\x18\x02 \x01(\x01\x12\x0c\n\x04gmin\x18\x03 \x01(\x01\x12\x0f\n\x07iabstol\x18\x04 \x01(\x01\x12\x0e\n\x06reltol\x18\x05 \x01(\x01"\xac\x02\n\x08\x41nalysis\x12"\n\x02op\x18\x01 \x01(\x0b\x32\x14.vlsir.spice.OpInputH\x00\x12"\n\x02\x64\x63\x18\x02 \x01(\x0b\x32\x14.vlsir.spice.DcInputH\x00\x12&\n\x04tran\x18\x03 \x01(\x0b\x32\x16.vlsir.spice.TranInputH\x00\x12"\n\x02\x61\x63\x18\x04 \x01(\x0b\x32\x14.vlsir.spice.AcInputH\x00\x12(\n\x05sweep\x18\n \x01(\x0b\x32\x17.vlsir.spice.SweepInputH\x00\x12(\n\x05monte\x18\x0b \x01(\x0b\x32\x17.vlsir.spice.MonteInputH\x00\x12\x32\n\x06\x63ustom\x18\x14 \x01(\x0b\x32 .vlsir.spice.CustomAnalysisInputH\x00\x42\x04\n\x02\x61n"\xb9\x02\n\x0e\x41nalysisResult\x12#\n\x02op\x18\x01 \x01(\x0b\x32\x15.vlsir.spice.OpResultH\x00\x12#\n\x02\x64\x63\x18\x02 \x01(\x0b\x32\x15.vlsir.spice.DcResultH\x00\x12\'\n\x04tran\x18\x03 \x01(\x0b\x32\x17.vlsir.spice.TranResultH\x00\x12#\n\x02\x61\x63\x18\x04 \x01(\x0b\x32\x15.vlsir.spice.AcResultH\x00\x12)\n\x05sweep\x18\n \x01(\x0b\x32\x18.vlsir.spice.SweepResultH\x00\x12)\n\x05monte\x18\x0b \x01(\x0b\x32\x18.vlsir.spice.MonteResultH\x00\x12\x33\n\x06\x63ustom\x18\x14 \x01(\x0b\x32!.vlsir.spice.CustomAnalysisResultH\x00\x42\x04\n\x02\x61n"E\n\x07OpInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"L\n\x08OpResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05"|\n\x07\x44\x63Input\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x12\n\nindep_name\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\xce\x01\n\x08\x44\x63Result\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x12\n\nindep_name\x18\x02 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01\x12=\n\x0cmeasurements\x18\n \x03(\x0b\x32\'.vlsir.spice.DcResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x04\x10\x05"\xbc\x01\n\tTranInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\r\n\x05tstop\x18\x02 \x01(\x01\x12\r\n\x05tstep\x18\x03 \x01(\x01\x12*\n\x02ic\x18\x04 \x03(\x0b\x32\x1e.vlsir.spice.TranInput.IcEntry\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control\x1a)\n\x07IcEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01"\xc4\x01\n\nTranResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x01\x12?\n\x0cmeasurements\x18\n \x03(\x0b\x32).vlsir.spice.TranResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05"$\n\nComplexNum\x12\n\n\x02re\x18\x01 \x01(\x01\x12\n\n\x02im\x18\x02 \x01(\x01"r\n\x07\x41\x63Input\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0e\n\x06\x66start\x18\x02 \x01(\x01\x12\r\n\x05\x66stop\x18\x03 \x01(\x01\x12\x0c\n\x04npts\x18\x04 \x01(\x04\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\xe1\x01\n\x08\x41\x63Result\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0c\n\x04\x66req\x18\x02 \x03(\x01\x12\x0f\n\x07signals\x18\x03 \x03(\t\x12%\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x17.vlsir.spice.ComplexNum\x12=\n\x0cmeasurements\x18\n \x03(\x0b\x32\'.vlsir.spice.AcResult.MeasurementsEntry\x1a\x33\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01J\x04\x08\x04\x10\x05"\xa0\x01\n\nSweepInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12!\n\x02\x61n\x18\x04 \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x82\x01\n\x0bSweepResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12\'\n\x02\x61n\x18\x04 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"\x87\x01\n\nMonteInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0c\n\x04npts\x18\x02 \x01(\x03\x12\x0c\n\x04seed\x18\x03 \x01(\x03\x12!\n\x02\x61n\x18\x04 \x03(\x0b\x32\x15.vlsir.spice.Analysis\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x82\x01\n\x0bMonteResult\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12!\n\x05sweep\x18\x03 \x01(\x0b\x32\x12.vlsir.spice.Sweep\x12\'\n\x02\x61n\x18\x04 \x03(\x0b\x32\x1b.vlsir.spice.AnalysisResult"^\n\x13\x43ustomAnalysisInput\x12\x15\n\ranalysis_name\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\x12#\n\x05\x63trls\x18\x05 \x03(\x0b\x32\x14.vlsir.spice.Control"\x16\n\x14\x43ustomAnalysisResult"\x8a\x01\n\x05Sweep\x12*\n\x06linear\x18\x01 \x01(\x0b\x32\x18.vlsir.spice.LinearSweepH\x00\x12$\n\x03log\x18\x02 \x01(\x0b\x32\x15.vlsir.spice.LogSweepH\x00\x12)\n\x06points\x18\x03 \x01(\x0b\x32\x17.vlsir.spice.PointSweepH\x00\x42\x04\n\x02tp"8\n\x0bLinearSweep\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04step\x18\x03 \x01(\x01"5\n\x08LogSweep\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04npts\x18\x03 \x01(\x01"8\n\nPointSweep\x12\x0e\n\x06points\x18\x01 \x03(\x01\x12\x0c\n\x04stop\x18\x02 \x01(\x01\x12\x0c\n\x04npts\x18\x03 \x01(\x01"\xe0\x01\n\x07\x43ontrol\x12\'\n\x07include\x18\x01 \x01(\x0b\x32\x14.vlsir.spice.IncludeH\x00\x12&\n\x03lib\x18\x02 \x01(\x0b\x32\x17.vlsir.spice.LibIncludeH\x00\x12!\n\x04save\x18\x05 \x01(\x0b\x32\x11.vlsir.spice.SaveH\x00\x12!\n\x04meas\x18\x06 \x01(\x0b\x32\x11.vlsir.spice.MeasH\x00\x12#\n\x05param\x18\x07 \x01(\x0b\x32\x12.vlsir.utils.ParamH\x00\x12\x11\n\x07literal\x18\n \x01(\tH\x00\x42\x06\n\x04\x63trl"k\n\x04Save\x12*\n\x04mode\x18\x01 \x01(\x0e\x32\x1a.vlsir.spice.Save.SaveModeH\x00\x12\x10\n\x06signal\x18\x02 \x01(\tH\x00"\x1d\n\x08SaveMode\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x42\x06\n\x04save"\x17\n\x07Include\x12\x0c\n\x04path\x18\x01 \x01(\t"+\n\nLibInclude\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07section\x18\x02 \x01(\t"9\n\x04Meas\x12\x15\n\ranalysis_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65xpr\x18\x03 \x01(\t"v\n\x06Signal\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x08quantity\x18\x02 \x01(\x0e\x32\x1c.vlsir.spice.Signal.Quantity".\n\x08Quantity\x12\x0b\n\x07VOLTAGE\x10\x00\x12\x0b\n\x07\x43URRENT\x10\x01\x12\x08\n\x04NONE\x10\x03\x32=\n\x05Spice\x12\x34\n\x03Sim\x12\x15.vlsir.spice.SimInput\x1a\x16.vlsir.spice.SimResultb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        utils__pb2.DESCRIPTOR,
        circuit__pb2.DESCRIPTOR,
    ],
)


_SAVE_SAVEMODE = _descriptor.EnumDescriptor(
    name="SaveMode",
    full_name="vlsir.spice.Save.SaveMode",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NONE",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ALL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3576,
    serialized_end=3605,
)
_sym_db.RegisterEnumDescriptor(_SAVE_SAVEMODE)

_SIGNAL_QUANTITY = _descriptor.EnumDescriptor(
    name="Quantity",
    full_name="vlsir.spice.Signal.Quantity",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="VOLTAGE",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CURRENT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="NONE",
            index=2,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3816,
    serialized_end=3862,
)
_sym_db.RegisterEnumDescriptor(_SIGNAL_QUANTITY)


_SIMINPUT = _descriptor.Descriptor(
    name="SimInput",
    full_name="vlsir.spice.SimInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="pkg",
            full_name="vlsir.spice.SimInput.pkg",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="top",
            full_name="vlsir.spice.SimInput.top",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="opts",
            full_name="vlsir.spice.SimInput.opts",
            index=2,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.SimInput.an",
            index=3,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.SimInput.ctrls",
            index=4,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=89,
    serialized_end=260,
)


_SIMRESULT = _descriptor.Descriptor(
    name="SimResult",
    full_name="vlsir.spice.SimResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.SimResult.an",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=262,
    serialized_end=314,
)


_SIMOPTIONS = _descriptor.Descriptor(
    name="SimOptions",
    full_name="vlsir.spice.SimOptions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="temp",
            full_name="vlsir.spice.SimOptions.temp",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tnom",
            full_name="vlsir.spice.SimOptions.tnom",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gmin",
            full_name="vlsir.spice.SimOptions.gmin",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="iabstol",
            full_name="vlsir.spice.SimOptions.iabstol",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reltol",
            full_name="vlsir.spice.SimOptions.reltol",
            index=4,
            number=5,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=316,
    serialized_end=403,
)


_ANALYSIS = _descriptor.Descriptor(
    name="Analysis",
    full_name="vlsir.spice.Analysis",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="op",
            full_name="vlsir.spice.Analysis.op",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dc",
            full_name="vlsir.spice.Analysis.dc",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tran",
            full_name="vlsir.spice.Analysis.tran",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ac",
            full_name="vlsir.spice.Analysis.ac",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.Analysis.sweep",
            index=4,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="monte",
            full_name="vlsir.spice.Analysis.monte",
            index=5,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="custom",
            full_name="vlsir.spice.Analysis.custom",
            index=6,
            number=20,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="an",
            full_name="vlsir.spice.Analysis.an",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=406,
    serialized_end=706,
)


_ANALYSISRESULT = _descriptor.Descriptor(
    name="AnalysisResult",
    full_name="vlsir.spice.AnalysisResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="op",
            full_name="vlsir.spice.AnalysisResult.op",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dc",
            full_name="vlsir.spice.AnalysisResult.dc",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tran",
            full_name="vlsir.spice.AnalysisResult.tran",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ac",
            full_name="vlsir.spice.AnalysisResult.ac",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.AnalysisResult.sweep",
            index=4,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="monte",
            full_name="vlsir.spice.AnalysisResult.monte",
            index=5,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="custom",
            full_name="vlsir.spice.AnalysisResult.custom",
            index=6,
            number=20,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="an",
            full_name="vlsir.spice.AnalysisResult.an",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=709,
    serialized_end=1022,
)


_OPINPUT = _descriptor.Descriptor(
    name="OpInput",
    full_name="vlsir.spice.OpInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.OpInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.OpInput.ctrls",
            index=1,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1024,
    serialized_end=1093,
)


_OPRESULT = _descriptor.Descriptor(
    name="OpResult",
    full_name="vlsir.spice.OpResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.OpResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signals",
            full_name="vlsir.spice.OpResult.signals",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="vlsir.spice.OpResult.data",
            index=2,
            number=5,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1095,
    serialized_end=1171,
)


_DCINPUT = _descriptor.Descriptor(
    name="DcInput",
    full_name="vlsir.spice.DcInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.DcInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="indep_name",
            full_name="vlsir.spice.DcInput.indep_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.DcInput.sweep",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.DcInput.ctrls",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1173,
    serialized_end=1297,
)


_DCRESULT_MEASUREMENTSENTRY = _descriptor.Descriptor(
    name="MeasurementsEntry",
    full_name="vlsir.spice.DcResult.MeasurementsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="vlsir.spice.DcResult.MeasurementsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="vlsir.spice.DcResult.MeasurementsEntry.value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1449,
    serialized_end=1500,
)

_DCRESULT = _descriptor.Descriptor(
    name="DcResult",
    full_name="vlsir.spice.DcResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.DcResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="indep_name",
            full_name="vlsir.spice.DcResult.indep_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signals",
            full_name="vlsir.spice.DcResult.signals",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="vlsir.spice.DcResult.data",
            index=3,
            number=5,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="measurements",
            full_name="vlsir.spice.DcResult.measurements",
            index=4,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_DCRESULT_MEASUREMENTSENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1300,
    serialized_end=1506,
)


_TRANINPUT_ICENTRY = _descriptor.Descriptor(
    name="IcEntry",
    full_name="vlsir.spice.TranInput.IcEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="vlsir.spice.TranInput.IcEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="vlsir.spice.TranInput.IcEntry.value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1656,
    serialized_end=1697,
)

_TRANINPUT = _descriptor.Descriptor(
    name="TranInput",
    full_name="vlsir.spice.TranInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.TranInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tstop",
            full_name="vlsir.spice.TranInput.tstop",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tstep",
            full_name="vlsir.spice.TranInput.tstep",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ic",
            full_name="vlsir.spice.TranInput.ic",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.TranInput.ctrls",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_TRANINPUT_ICENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1509,
    serialized_end=1697,
)


_TRANRESULT_MEASUREMENTSENTRY = _descriptor.Descriptor(
    name="MeasurementsEntry",
    full_name="vlsir.spice.TranResult.MeasurementsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="vlsir.spice.TranResult.MeasurementsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="vlsir.spice.TranResult.MeasurementsEntry.value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1449,
    serialized_end=1500,
)

_TRANRESULT = _descriptor.Descriptor(
    name="TranResult",
    full_name="vlsir.spice.TranResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.TranResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signals",
            full_name="vlsir.spice.TranResult.signals",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="vlsir.spice.TranResult.data",
            index=2,
            number=5,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="measurements",
            full_name="vlsir.spice.TranResult.measurements",
            index=3,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_TRANRESULT_MEASUREMENTSENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1700,
    serialized_end=1896,
)


_COMPLEXNUM = _descriptor.Descriptor(
    name="ComplexNum",
    full_name="vlsir.spice.ComplexNum",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="re",
            full_name="vlsir.spice.ComplexNum.re",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="im",
            full_name="vlsir.spice.ComplexNum.im",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1898,
    serialized_end=1934,
)


_ACINPUT = _descriptor.Descriptor(
    name="AcInput",
    full_name="vlsir.spice.AcInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.AcInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fstart",
            full_name="vlsir.spice.AcInput.fstart",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fstop",
            full_name="vlsir.spice.AcInput.fstop",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="npts",
            full_name="vlsir.spice.AcInput.npts",
            index=3,
            number=4,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.AcInput.ctrls",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1936,
    serialized_end=2050,
)


_ACRESULT_MEASUREMENTSENTRY = _descriptor.Descriptor(
    name="MeasurementsEntry",
    full_name="vlsir.spice.AcResult.MeasurementsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="vlsir.spice.AcResult.MeasurementsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="vlsir.spice.AcResult.MeasurementsEntry.value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1449,
    serialized_end=1500,
)

_ACRESULT = _descriptor.Descriptor(
    name="AcResult",
    full_name="vlsir.spice.AcResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.AcResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="freq",
            full_name="vlsir.spice.AcResult.freq",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signals",
            full_name="vlsir.spice.AcResult.signals",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="vlsir.spice.AcResult.data",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="measurements",
            full_name="vlsir.spice.AcResult.measurements",
            index=4,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_ACRESULT_MEASUREMENTSENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2053,
    serialized_end=2278,
)


_SWEEPINPUT = _descriptor.Descriptor(
    name="SweepInput",
    full_name="vlsir.spice.SweepInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.SweepInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="variable",
            full_name="vlsir.spice.SweepInput.variable",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.SweepInput.sweep",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.SweepInput.an",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.SweepInput.ctrls",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2281,
    serialized_end=2441,
)


_SWEEPRESULT = _descriptor.Descriptor(
    name="SweepResult",
    full_name="vlsir.spice.SweepResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.SweepResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="variable",
            full_name="vlsir.spice.SweepResult.variable",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.SweepResult.sweep",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.SweepResult.an",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2444,
    serialized_end=2574,
)


_MONTEINPUT = _descriptor.Descriptor(
    name="MonteInput",
    full_name="vlsir.spice.MonteInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.MonteInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="npts",
            full_name="vlsir.spice.MonteInput.npts",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="seed",
            full_name="vlsir.spice.MonteInput.seed",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.MonteInput.an",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.MonteInput.ctrls",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2577,
    serialized_end=2712,
)


_MONTERESULT = _descriptor.Descriptor(
    name="MonteResult",
    full_name="vlsir.spice.MonteResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.MonteResult.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="variable",
            full_name="vlsir.spice.MonteResult.variable",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sweep",
            full_name="vlsir.spice.MonteResult.sweep",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="an",
            full_name="vlsir.spice.MonteResult.an",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2715,
    serialized_end=2845,
)


_CUSTOMANALYSISINPUT = _descriptor.Descriptor(
    name="CustomAnalysisInput",
    full_name="vlsir.spice.CustomAnalysisInput",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_name",
            full_name="vlsir.spice.CustomAnalysisInput.analysis_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cmd",
            full_name="vlsir.spice.CustomAnalysisInput.cmd",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ctrls",
            full_name="vlsir.spice.CustomAnalysisInput.ctrls",
            index=2,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2847,
    serialized_end=2941,
)


_CUSTOMANALYSISRESULT = _descriptor.Descriptor(
    name="CustomAnalysisResult",
    full_name="vlsir.spice.CustomAnalysisResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2943,
    serialized_end=2965,
)


_SWEEP = _descriptor.Descriptor(
    name="Sweep",
    full_name="vlsir.spice.Sweep",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="linear",
            full_name="vlsir.spice.Sweep.linear",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="log",
            full_name="vlsir.spice.Sweep.log",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="points",
            full_name="vlsir.spice.Sweep.points",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="tp",
            full_name="vlsir.spice.Sweep.tp",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=2968,
    serialized_end=3106,
)


_LINEARSWEEP = _descriptor.Descriptor(
    name="LinearSweep",
    full_name="vlsir.spice.LinearSweep",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="start",
            full_name="vlsir.spice.LinearSweep.start",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stop",
            full_name="vlsir.spice.LinearSweep.stop",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="step",
            full_name="vlsir.spice.LinearSweep.step",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3108,
    serialized_end=3164,
)


_LOGSWEEP = _descriptor.Descriptor(
    name="LogSweep",
    full_name="vlsir.spice.LogSweep",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="start",
            full_name="vlsir.spice.LogSweep.start",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stop",
            full_name="vlsir.spice.LogSweep.stop",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="npts",
            full_name="vlsir.spice.LogSweep.npts",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3166,
    serialized_end=3219,
)


_POINTSWEEP = _descriptor.Descriptor(
    name="PointSweep",
    full_name="vlsir.spice.PointSweep",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="points",
            full_name="vlsir.spice.PointSweep.points",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stop",
            full_name="vlsir.spice.PointSweep.stop",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="npts",
            full_name="vlsir.spice.PointSweep.npts",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3221,
    serialized_end=3277,
)


_CONTROL = _descriptor.Descriptor(
    name="Control",
    full_name="vlsir.spice.Control",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="include",
            full_name="vlsir.spice.Control.include",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lib",
            full_name="vlsir.spice.Control.lib",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="save",
            full_name="vlsir.spice.Control.save",
            index=2,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="meas",
            full_name="vlsir.spice.Control.meas",
            index=3,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="param",
            full_name="vlsir.spice.Control.param",
            index=4,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="literal",
            full_name="vlsir.spice.Control.literal",
            index=5,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="ctrl",
            full_name="vlsir.spice.Control.ctrl",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=3280,
    serialized_end=3504,
)


_SAVE = _descriptor.Descriptor(
    name="Save",
    full_name="vlsir.spice.Save",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="mode",
            full_name="vlsir.spice.Save.mode",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signal",
            full_name="vlsir.spice.Save.signal",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_SAVE_SAVEMODE,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="save",
            full_name="vlsir.spice.Save.save",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=3506,
    serialized_end=3613,
)


_INCLUDE = _descriptor.Descriptor(
    name="Include",
    full_name="vlsir.spice.Include",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="path",
            full_name="vlsir.spice.Include.path",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3615,
    serialized_end=3638,
)


_LIBINCLUDE = _descriptor.Descriptor(
    name="LibInclude",
    full_name="vlsir.spice.LibInclude",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="path",
            full_name="vlsir.spice.LibInclude.path",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="section",
            full_name="vlsir.spice.LibInclude.section",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3640,
    serialized_end=3683,
)


_MEAS = _descriptor.Descriptor(
    name="Meas",
    full_name="vlsir.spice.Meas",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_type",
            full_name="vlsir.spice.Meas.analysis_type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="vlsir.spice.Meas.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="expr",
            full_name="vlsir.spice.Meas.expr",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3685,
    serialized_end=3742,
)


_SIGNAL = _descriptor.Descriptor(
    name="Signal",
    full_name="vlsir.spice.Signal",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="vlsir.spice.Signal.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="quantity",
            full_name="vlsir.spice.Signal.quantity",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_SIGNAL_QUANTITY,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3744,
    serialized_end=3862,
)

_SIMINPUT.fields_by_name["pkg"].message_type = circuit__pb2._PACKAGE
_SIMINPUT.fields_by_name["opts"].message_type = _SIMOPTIONS
_SIMINPUT.fields_by_name["an"].message_type = _ANALYSIS
_SIMINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_SIMRESULT.fields_by_name["an"].message_type = _ANALYSISRESULT
_ANALYSIS.fields_by_name["op"].message_type = _OPINPUT
_ANALYSIS.fields_by_name["dc"].message_type = _DCINPUT
_ANALYSIS.fields_by_name["tran"].message_type = _TRANINPUT
_ANALYSIS.fields_by_name["ac"].message_type = _ACINPUT
_ANALYSIS.fields_by_name["sweep"].message_type = _SWEEPINPUT
_ANALYSIS.fields_by_name["monte"].message_type = _MONTEINPUT
_ANALYSIS.fields_by_name["custom"].message_type = _CUSTOMANALYSISINPUT
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["op"])
_ANALYSIS.fields_by_name["op"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["dc"])
_ANALYSIS.fields_by_name["dc"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["tran"])
_ANALYSIS.fields_by_name["tran"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["ac"])
_ANALYSIS.fields_by_name["ac"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["sweep"])
_ANALYSIS.fields_by_name["sweep"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["monte"])
_ANALYSIS.fields_by_name["monte"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSIS.oneofs_by_name["an"].fields.append(_ANALYSIS.fields_by_name["custom"])
_ANALYSIS.fields_by_name["custom"].containing_oneof = _ANALYSIS.oneofs_by_name["an"]
_ANALYSISRESULT.fields_by_name["op"].message_type = _OPRESULT
_ANALYSISRESULT.fields_by_name["dc"].message_type = _DCRESULT
_ANALYSISRESULT.fields_by_name["tran"].message_type = _TRANRESULT
_ANALYSISRESULT.fields_by_name["ac"].message_type = _ACRESULT
_ANALYSISRESULT.fields_by_name["sweep"].message_type = _SWEEPRESULT
_ANALYSISRESULT.fields_by_name["monte"].message_type = _MONTERESULT
_ANALYSISRESULT.fields_by_name["custom"].message_type = _CUSTOMANALYSISRESULT
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(_ANALYSISRESULT.fields_by_name["op"])
_ANALYSISRESULT.fields_by_name["op"].containing_oneof = _ANALYSISRESULT.oneofs_by_name[
    "an"
]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(_ANALYSISRESULT.fields_by_name["dc"])
_ANALYSISRESULT.fields_by_name["dc"].containing_oneof = _ANALYSISRESULT.oneofs_by_name[
    "an"
]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(
    _ANALYSISRESULT.fields_by_name["tran"]
)
_ANALYSISRESULT.fields_by_name[
    "tran"
].containing_oneof = _ANALYSISRESULT.oneofs_by_name["an"]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(_ANALYSISRESULT.fields_by_name["ac"])
_ANALYSISRESULT.fields_by_name["ac"].containing_oneof = _ANALYSISRESULT.oneofs_by_name[
    "an"
]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(
    _ANALYSISRESULT.fields_by_name["sweep"]
)
_ANALYSISRESULT.fields_by_name[
    "sweep"
].containing_oneof = _ANALYSISRESULT.oneofs_by_name["an"]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(
    _ANALYSISRESULT.fields_by_name["monte"]
)
_ANALYSISRESULT.fields_by_name[
    "monte"
].containing_oneof = _ANALYSISRESULT.oneofs_by_name["an"]
_ANALYSISRESULT.oneofs_by_name["an"].fields.append(
    _ANALYSISRESULT.fields_by_name["custom"]
)
_ANALYSISRESULT.fields_by_name[
    "custom"
].containing_oneof = _ANALYSISRESULT.oneofs_by_name["an"]
_OPINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_DCINPUT.fields_by_name["sweep"].message_type = _SWEEP
_DCINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_DCRESULT_MEASUREMENTSENTRY.containing_type = _DCRESULT
_DCRESULT.fields_by_name["measurements"].message_type = _DCRESULT_MEASUREMENTSENTRY
_TRANINPUT_ICENTRY.containing_type = _TRANINPUT
_TRANINPUT.fields_by_name["ic"].message_type = _TRANINPUT_ICENTRY
_TRANINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_TRANRESULT_MEASUREMENTSENTRY.containing_type = _TRANRESULT
_TRANRESULT.fields_by_name["measurements"].message_type = _TRANRESULT_MEASUREMENTSENTRY
_ACINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_ACRESULT_MEASUREMENTSENTRY.containing_type = _ACRESULT
_ACRESULT.fields_by_name["data"].message_type = _COMPLEXNUM
_ACRESULT.fields_by_name["measurements"].message_type = _ACRESULT_MEASUREMENTSENTRY
_SWEEPINPUT.fields_by_name["sweep"].message_type = _SWEEP
_SWEEPINPUT.fields_by_name["an"].message_type = _ANALYSIS
_SWEEPINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_SWEEPRESULT.fields_by_name["sweep"].message_type = _SWEEP
_SWEEPRESULT.fields_by_name["an"].message_type = _ANALYSISRESULT
_MONTEINPUT.fields_by_name["an"].message_type = _ANALYSIS
_MONTEINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_MONTERESULT.fields_by_name["sweep"].message_type = _SWEEP
_MONTERESULT.fields_by_name["an"].message_type = _ANALYSISRESULT
_CUSTOMANALYSISINPUT.fields_by_name["ctrls"].message_type = _CONTROL
_SWEEP.fields_by_name["linear"].message_type = _LINEARSWEEP
_SWEEP.fields_by_name["log"].message_type = _LOGSWEEP
_SWEEP.fields_by_name["points"].message_type = _POINTSWEEP
_SWEEP.oneofs_by_name["tp"].fields.append(_SWEEP.fields_by_name["linear"])
_SWEEP.fields_by_name["linear"].containing_oneof = _SWEEP.oneofs_by_name["tp"]
_SWEEP.oneofs_by_name["tp"].fields.append(_SWEEP.fields_by_name["log"])
_SWEEP.fields_by_name["log"].containing_oneof = _SWEEP.oneofs_by_name["tp"]
_SWEEP.oneofs_by_name["tp"].fields.append(_SWEEP.fields_by_name["points"])
_SWEEP.fields_by_name["points"].containing_oneof = _SWEEP.oneofs_by_name["tp"]
_CONTROL.fields_by_name["include"].message_type = _INCLUDE
_CONTROL.fields_by_name["lib"].message_type = _LIBINCLUDE
_CONTROL.fields_by_name["save"].message_type = _SAVE
_CONTROL.fields_by_name["meas"].message_type = _MEAS
_CONTROL.fields_by_name["param"].message_type = utils__pb2._PARAM
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["include"])
_CONTROL.fields_by_name["include"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["lib"])
_CONTROL.fields_by_name["lib"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["save"])
_CONTROL.fields_by_name["save"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["meas"])
_CONTROL.fields_by_name["meas"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["param"])
_CONTROL.fields_by_name["param"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_CONTROL.oneofs_by_name["ctrl"].fields.append(_CONTROL.fields_by_name["literal"])
_CONTROL.fields_by_name["literal"].containing_oneof = _CONTROL.oneofs_by_name["ctrl"]
_SAVE.fields_by_name["mode"].enum_type = _SAVE_SAVEMODE
_SAVE_SAVEMODE.containing_type = _SAVE
_SAVE.oneofs_by_name["save"].fields.append(_SAVE.fields_by_name["mode"])
_SAVE.fields_by_name["mode"].containing_oneof = _SAVE.oneofs_by_name["save"]
_SAVE.oneofs_by_name["save"].fields.append(_SAVE.fields_by_name["signal"])
_SAVE.fields_by_name["signal"].containing_oneof = _SAVE.oneofs_by_name["save"]
_SIGNAL.fields_by_name["quantity"].enum_type = _SIGNAL_QUANTITY
_SIGNAL_QUANTITY.containing_type = _SIGNAL
DESCRIPTOR.message_types_by_name["SimInput"] = _SIMINPUT
DESCRIPTOR.message_types_by_name["SimResult"] = _SIMRESULT
DESCRIPTOR.message_types_by_name["SimOptions"] = _SIMOPTIONS
DESCRIPTOR.message_types_by_name["Analysis"] = _ANALYSIS
DESCRIPTOR.message_types_by_name["AnalysisResult"] = _ANALYSISRESULT
DESCRIPTOR.message_types_by_name["OpInput"] = _OPINPUT
DESCRIPTOR.message_types_by_name["OpResult"] = _OPRESULT
DESCRIPTOR.message_types_by_name["DcInput"] = _DCINPUT
DESCRIPTOR.message_types_by_name["DcResult"] = _DCRESULT
DESCRIPTOR.message_types_by_name["TranInput"] = _TRANINPUT
DESCRIPTOR.message_types_by_name["TranResult"] = _TRANRESULT
DESCRIPTOR.message_types_by_name["ComplexNum"] = _COMPLEXNUM
DESCRIPTOR.message_types_by_name["AcInput"] = _ACINPUT
DESCRIPTOR.message_types_by_name["AcResult"] = _ACRESULT
DESCRIPTOR.message_types_by_name["SweepInput"] = _SWEEPINPUT
DESCRIPTOR.message_types_by_name["SweepResult"] = _SWEEPRESULT
DESCRIPTOR.message_types_by_name["MonteInput"] = _MONTEINPUT
DESCRIPTOR.message_types_by_name["MonteResult"] = _MONTERESULT
DESCRIPTOR.message_types_by_name["CustomAnalysisInput"] = _CUSTOMANALYSISINPUT
DESCRIPTOR.message_types_by_name["CustomAnalysisResult"] = _CUSTOMANALYSISRESULT
DESCRIPTOR.message_types_by_name["Sweep"] = _SWEEP
DESCRIPTOR.message_types_by_name["LinearSweep"] = _LINEARSWEEP
DESCRIPTOR.message_types_by_name["LogSweep"] = _LOGSWEEP
DESCRIPTOR.message_types_by_name["PointSweep"] = _POINTSWEEP
DESCRIPTOR.message_types_by_name["Control"] = _CONTROL
DESCRIPTOR.message_types_by_name["Save"] = _SAVE
DESCRIPTOR.message_types_by_name["Include"] = _INCLUDE
DESCRIPTOR.message_types_by_name["LibInclude"] = _LIBINCLUDE
DESCRIPTOR.message_types_by_name["Meas"] = _MEAS
DESCRIPTOR.message_types_by_name["Signal"] = _SIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimInput = _reflection.GeneratedProtocolMessageType(
    "SimInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimInput)
    },
)
_sym_db.RegisterMessage(SimInput)

SimResult = _reflection.GeneratedProtocolMessageType(
    "SimResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimResult)
    },
)
_sym_db.RegisterMessage(SimResult)

SimOptions = _reflection.GeneratedProtocolMessageType(
    "SimOptions",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIMOPTIONS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SimOptions)
    },
)
_sym_db.RegisterMessage(SimOptions)

Analysis = _reflection.GeneratedProtocolMessageType(
    "Analysis",
    (_message.Message,),
    {
        "DESCRIPTOR": _ANALYSIS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Analysis)
    },
)
_sym_db.RegisterMessage(Analysis)

AnalysisResult = _reflection.GeneratedProtocolMessageType(
    "AnalysisResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _ANALYSISRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AnalysisResult)
    },
)
_sym_db.RegisterMessage(AnalysisResult)

OpInput = _reflection.GeneratedProtocolMessageType(
    "OpInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.OpInput)
    },
)
_sym_db.RegisterMessage(OpInput)

OpResult = _reflection.GeneratedProtocolMessageType(
    "OpResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.OpResult)
    },
)
_sym_db.RegisterMessage(OpResult)

DcInput = _reflection.GeneratedProtocolMessageType(
    "DcInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _DCINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.DcInput)
    },
)
_sym_db.RegisterMessage(DcInput)

DcResult = _reflection.GeneratedProtocolMessageType(
    "DcResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _DCRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.DcResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _DCRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.DcResult)
    },
)
_sym_db.RegisterMessage(DcResult)
_sym_db.RegisterMessage(DcResult.MeasurementsEntry)

TranInput = _reflection.GeneratedProtocolMessageType(
    "TranInput",
    (_message.Message,),
    {
        "IcEntry": _reflection.GeneratedProtocolMessageType(
            "IcEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRANINPUT_ICENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.TranInput.IcEntry)
            },
        ),
        "DESCRIPTOR": _TRANINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.TranInput)
    },
)
_sym_db.RegisterMessage(TranInput)
_sym_db.RegisterMessage(TranInput.IcEntry)

TranResult = _reflection.GeneratedProtocolMessageType(
    "TranResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRANRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.TranResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _TRANRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.TranResult)
    },
)
_sym_db.RegisterMessage(TranResult)
_sym_db.RegisterMessage(TranResult.MeasurementsEntry)

ComplexNum = _reflection.GeneratedProtocolMessageType(
    "ComplexNum",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLEXNUM,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.ComplexNum)
    },
)
_sym_db.RegisterMessage(ComplexNum)

AcInput = _reflection.GeneratedProtocolMessageType(
    "AcInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _ACINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AcInput)
    },
)
_sym_db.RegisterMessage(AcInput)

AcResult = _reflection.GeneratedProtocolMessageType(
    "AcResult",
    (_message.Message,),
    {
        "MeasurementsEntry": _reflection.GeneratedProtocolMessageType(
            "MeasurementsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _ACRESULT_MEASUREMENTSENTRY,
                "__module__": "spice_pb2"
                # @@protoc_insertion_point(class_scope:vlsir.spice.AcResult.MeasurementsEntry)
            },
        ),
        "DESCRIPTOR": _ACRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.AcResult)
    },
)
_sym_db.RegisterMessage(AcResult)
_sym_db.RegisterMessage(AcResult.MeasurementsEntry)

SweepInput = _reflection.GeneratedProtocolMessageType(
    "SweepInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEPINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SweepInput)
    },
)
_sym_db.RegisterMessage(SweepInput)

SweepResult = _reflection.GeneratedProtocolMessageType(
    "SweepResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEPRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.SweepResult)
    },
)
_sym_db.RegisterMessage(SweepResult)

MonteInput = _reflection.GeneratedProtocolMessageType(
    "MonteInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _MONTEINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.MonteInput)
    },
)
_sym_db.RegisterMessage(MonteInput)

MonteResult = _reflection.GeneratedProtocolMessageType(
    "MonteResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _MONTERESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.MonteResult)
    },
)
_sym_db.RegisterMessage(MonteResult)

CustomAnalysisInput = _reflection.GeneratedProtocolMessageType(
    "CustomAnalysisInput",
    (_message.Message,),
    {
        "DESCRIPTOR": _CUSTOMANALYSISINPUT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.CustomAnalysisInput)
    },
)
_sym_db.RegisterMessage(CustomAnalysisInput)

CustomAnalysisResult = _reflection.GeneratedProtocolMessageType(
    "CustomAnalysisResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _CUSTOMANALYSISRESULT,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.CustomAnalysisResult)
    },
)
_sym_db.RegisterMessage(CustomAnalysisResult)

Sweep = _reflection.GeneratedProtocolMessageType(
    "Sweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _SWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Sweep)
    },
)
_sym_db.RegisterMessage(Sweep)

LinearSweep = _reflection.GeneratedProtocolMessageType(
    "LinearSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINEARSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LinearSweep)
    },
)
_sym_db.RegisterMessage(LinearSweep)

LogSweep = _reflection.GeneratedProtocolMessageType(
    "LogSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOGSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LogSweep)
    },
)
_sym_db.RegisterMessage(LogSweep)

PointSweep = _reflection.GeneratedProtocolMessageType(
    "PointSweep",
    (_message.Message,),
    {
        "DESCRIPTOR": _POINTSWEEP,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.PointSweep)
    },
)
_sym_db.RegisterMessage(PointSweep)

Control = _reflection.GeneratedProtocolMessageType(
    "Control",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONTROL,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Control)
    },
)
_sym_db.RegisterMessage(Control)

Save = _reflection.GeneratedProtocolMessageType(
    "Save",
    (_message.Message,),
    {
        "DESCRIPTOR": _SAVE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Save)
    },
)
_sym_db.RegisterMessage(Save)

Include = _reflection.GeneratedProtocolMessageType(
    "Include",
    (_message.Message,),
    {
        "DESCRIPTOR": _INCLUDE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Include)
    },
)
_sym_db.RegisterMessage(Include)

LibInclude = _reflection.GeneratedProtocolMessageType(
    "LibInclude",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIBINCLUDE,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.LibInclude)
    },
)
_sym_db.RegisterMessage(LibInclude)

Meas = _reflection.GeneratedProtocolMessageType(
    "Meas",
    (_message.Message,),
    {
        "DESCRIPTOR": _MEAS,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Meas)
    },
)
_sym_db.RegisterMessage(Meas)

Signal = _reflection.GeneratedProtocolMessageType(
    "Signal",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIGNAL,
        "__module__": "spice_pb2"
        # @@protoc_insertion_point(class_scope:vlsir.spice.Signal)
    },
)
_sym_db.RegisterMessage(Signal)


_DCRESULT_MEASUREMENTSENTRY._options = None
_TRANINPUT_ICENTRY._options = None
_TRANRESULT_MEASUREMENTSENTRY._options = None
_ACRESULT_MEASUREMENTSENTRY._options = None

_SPICE = _descriptor.ServiceDescriptor(
    name="Spice",
    full_name="vlsir.spice.Spice",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=3864,
    serialized_end=3925,
    methods=[
        _descriptor.MethodDescriptor(
            name="Sim",
            full_name="vlsir.spice.Spice.Sim",
            index=0,
            containing_service=None,
            input_type=_SIMINPUT,
            output_type=_SIMRESULT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_SPICE)

DESCRIPTOR.services_by_name["Spice"] = _SPICE

# @@protoc_insertion_point(module_scope)
